==> sourcegit-2025.33.gh.tar.gz: sourcegit-2025.33/THIRD-PARTY-LICENSES.md <==
# Third-Party Licenses

The project uses the following third-party libraries or assets

## Packages

### AvaloniaUI

- **Source**: https://github.com/AvaloniaUI/Avalonia
- **Version**: 11.3.3
- **License**: MIT License
- **License Link**: https://github.com/AvaloniaUI/Avalonia/blob/master/licence.md

### AvaloniaEdit

- **Source**: https://github.com/AvaloniaUI/AvaloniaEdit
- **Version**: 11.3.0
- **License**: MIT License
- **License Link**: https://github.com/AvaloniaUI/AvaloniaEdit/blob/master/LICENSE

### LiveChartsCore.SkiaSharpView.Avalonia

- **Source**: https://github.com/beto-rodriguez/LiveCharts2
- **Version**: 2.0.0-rc5.4
- **License**: MIT License
- **License Link**: https://github.com/beto-rodriguez/LiveCharts2/blob/master/LICENSE

### TextMateSharp

- **Source**: https://github.com/danipen/TextMateSharp
- **Version**: 1.0.70
- **License**: MIT License
- **License Link**: https://github.com/danipen/TextMateSharp/blob/master/LICENSE.md

### OpenAI .NET SDK

- **Source**: https://github.com/openai/openai-dotnet
- **Version**: 2.3.0
- **License**: MIT License
- **License Link**: https://github.com/openai/openai-dotnet/blob/main/LICENSE

### Azure.AI.OpenAI

- **Source**: https://github.com/Azure/azure-sdk-for-net
- **Version**: 2.2.0-beta.5
- **License**: MIT License
- **License Link**: https://github.com/Azure/azure-sdk-for-net/blob/main/LICENSE.txt

### BitMiracle.LibTiff.NET

- **Source**: https://github.com/BitMiracle/libtiff.net
- **Version**: 2.4.660
- **License**: New BSD License
- **License Link**: https://github.com/BitMiracle/libtiff.net/blob/master/license.txt

### Pfim

- **Source**: https://github.com/nickbabcock/Pfim
- **Version**: 0.11.3
- **License**: MIT License
- **License Link**: https://github.com/nickbabcock/Pfim/blob/master/LICENSE.txt

## Fonts

### JetBrainsMono

- **Source**: https://github.com/JetBrains/JetBrainsMono
- **Commit**: v2.304
- **License**: SIL Open Font License, Version 1.1
- **License Link**: https://github.com/JetBrains/JetBrainsMono/blob/v2.304/OFL.txt

## Grammar Files

### haxe-TmLanguage

- **Source**: https://github.com/vshaxe/haxe-TmLanguage
- **Commit**: ddad8b4c6d0781ac20be0481174ec1be772c5da5
- **License**: MIT License
- **License Link**: https://github.com/vshaxe/haxe-TmLanguage/blob/ddad8b4c6d0781ac20be0481174ec1be772c5da5/LICENSE.md

### coc-toml

- **Source**: https://github.com/kkiyama117/coc-toml
- **Commit**: aac3e0c65955c03314b2733041b19f903b7cc447
- **License**: MIT License
- **License Link**: https://github.com/kkiyama117/coc-toml/blob/aac3e0c65955c03314b2733041b19f903b7cc447/LICENSE

### eclipse-buildship

- **Source**: https://github.com/eclipse/buildship
- **Commit**: 6bb773e7692f913dec27105129ebe388de34e68b
- **License**: Eclipse Public License 1.0
- **License Link**: https://github.com/eclipse-buildship/buildship/blob/6bb773e7692f913dec27105129ebe388de34e68b/README.md

### vscode-jsp-lang

- **Source**: https://github.com/samuel-weinhardt/vscode-jsp-lang
- **Commit**: 0e89ecdb13650dbbe5a1e85b47b2e1530bf2f355
- **License**: MIT License
- **License Link**: https://github.com/samuel-weinhardt/vscode-jsp-lang/blob/0e89ecdb13650dbbe5a1e85b47b2e1530bf2f355/LICENSE

==> sourcegit-2025.34.gh.tar.gz: sourcegit-2025.34/THIRD-PARTY-LICENSES.md <==
# Third-Party Licenses

The project uses the following third-party libraries or assets

## Packages

### AvaloniaUI

- **Source**: https://github.com/AvaloniaUI/Avalonia
- **Version**: 11.3.5
- **License**: MIT License
- **License Link**: https://github.com/AvaloniaUI/Avalonia/blob/master/licence.md

### AvaloniaEdit

- **Source**: https://github.com/AvaloniaUI/AvaloniaEdit
- **Version**: 11.3.0
- **License**: MIT License
- **License Link**: https://github.com/AvaloniaUI/AvaloniaEdit/blob/master/LICENSE

### LiveChartsCore.SkiaSharpView.Avalonia

- **Source**: https://github.com/beto-rodriguez/LiveCharts2
- **Version**: 2.0.0-rc5.4
- **License**: MIT License
- **License Link**: https://github.com/beto-rodriguez/LiveCharts2/blob/master/LICENSE

### TextMateSharp

- **Source**: https://github.com/danipen/TextMateSharp
- **Version**: 1.0.70
- **License**: MIT License
- **License Link**: https://github.com/danipen/TextMateSharp/blob/master/LICENSE.md

### OpenAI .NET SDK

- **Source**: https://github.com/openai/openai-dotnet
- **Version**: 2.3.0
- **License**: MIT License
- **License Link**: https://github.com/openai/openai-dotnet/blob/main/LICENSE

### Azure.AI.OpenAI

- **Source**: https://github.com/Azure/azure-sdk-for-net
- **Version**: 2.3.0-beta.2
- **License**: MIT License
- **License Link**: https://github.com/Azure/azure-sdk-for-net/blob/main/LICENSE.txt

### BitMiracle.LibTiff.NET

- **Source**: https://github.com/BitMiracle/libtiff.net
- **Version**: 2.4.660
- **License**: New BSD License
- **License Link**: https://github.com/BitMiracle/libtiff.net/blob/master/license.txt

### Pfim

- **Source**: https://github.com/nickbabcock/Pfim
- **Version**: 0.11.3
- **License**: MIT License
- **License Link**: https://github.com/nickbabcock/Pfim/blob/master/LICENSE.txt

## Fonts

### JetBrainsMono

- **Source**: https://github.com/JetBrains/JetBrainsMono
- **Commit**: v2.304
- **License**: SIL Open Font License, Version 1.1
- **License Link**: https://github.com/JetBrains/JetBrainsMono/blob/v2.304/OFL.txt

## Grammar Files

### haxe-TmLanguage

- **Source**: https://github.com/vshaxe/haxe-TmLanguage
- **Commit**: ddad8b4c6d0781ac20be0481174ec1be772c5da5
- **License**: MIT License
- **License Link**: https://github.com/vshaxe/haxe-TmLanguage/blob/ddad8b4c6d0781ac20be0481174ec1be772c5da5/LICENSE.md

### coc-toml

- **Source**: https://github.com/kkiyama117/coc-toml
- **Commit**: aac3e0c65955c03314b2733041b19f903b7cc447
- **License**: MIT License
- **License Link**: https://github.com/kkiyama117/coc-toml/blob/aac3e0c65955c03314b2733041b19f903b7cc447/LICENSE

### eclipse-buildship

- **Source**: https://github.com/eclipse/buildship
- **Commit**: 6bb773e7692f913dec27105129ebe388de34e68b
- **License**: Eclipse Public License 1.0
- **License Link**: https://github.com/eclipse-buildship/buildship/blob/6bb773e7692f913dec27105129ebe388de34e68b/README.md

### vscode-jsp-lang

- **Source**: https://github.com/samuel-weinhardt/vscode-jsp-lang
- **Commit**: 0e89ecdb13650dbbe5a1e85b47b2e1530bf2f355
- **License**: MIT License
- **License Link**: https://github.com/samuel-weinhardt/vscode-jsp-lang/blob/0e89ecdb13650dbbe5a1e85b47b2e1530bf2f355/LICENSE

### vuejs-language-tools

- **Source**: https://github.com/vuejs/language-tools
- **Commit**: 68d98dc57f8486c2946ae28dc86bf8e91d45da4d
- **License**: MIT License
- **License Link**: https://github.com/vuejs/language-tools/blob/68d98dc57f8486c2946ae28dc86bf8e91d45da4d/LICENSE
